import { S3Origin } from "aws-cdk-lib/aws-cloudfront-origins";
import { Runtime } from "aws-cdk-lib/aws-lambda";
import { NodejsFunction } from "aws-cdk-lib/aws-lambda-nodejs";
import { Bucket, BucketProps } from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { ServerOptions } from "./types";
/**
 * The base class for all constructs.
 */
export declare class AstroSiteConstruct extends Construct {
    constructor(scope: Construct, id: string);
    /**
     * New bucket
     *
     * @param scope
     * @param staticDir
     * @param props
     * @returns
     */
    newBucket(scope: Construct, staticDir: string, props?: BucketProps): Bucket;
    /**
     * New nodejs function
     *
     * @param scope
     * @param serverEntry
     * @param props
     * @returns
     */
    newFunction(scope: Construct, serverEntry: string, props?: ServerOptions): NodejsFunction;
    /**
     * New S3 origin
     * @param scope
     * @param bucket
     * @returns
     */
    newS3Origin(scope: Construct, bucket: Bucket): S3Origin;
    /**
     * Transform string to Runtime
     *
     * @param str
     * @returns
     * @default Runtime.NODEJS_18_X
     */
    strToRuntime(str?: string): Runtime;
    /**
     * Parse routes from directory
     * if the item is directory will parse to /item/*
     * if the item is file will parse to /item
     *
     * @param dir
     * @returns
     */
    parseRoutesFromDir(dir: string): string[];
}
